<?php
/***************************************************************************
 *                                                                          *
 *				   (c) 2013 Re:Desk Development Team    				   *
 *                                                                          *
 * This  is  commercial  software,  only  users  who have purchased a valid *
 * license  and  accept  to the terms of the  License Agreement can install *
 * and use this program.                                                    *
 *                                                                          *
 ****************************************************************************
 * PLEASE READ THE FULL TEXT  OF THE SOFTWARE  LICENSE   AGREEMENT  IN  THE *
 * "copyright.txt" FILE PROVIDED WITH THIS DISTRIBUTION PACKAGE.            *
 ****************************************************************************/

class InstallController extends CController
{
	const PHP_VERSION = '5.1.0';
	const CONFIG_FILE_NAME = 'main.local.php';
	const CRON_CONFIG_FILE_NAME = 'cron.local.php';

	public $is_redirect = false;

	/**
	 * @property string the default layout for the controller view. Defaults to '//layouts/column1',
	 * meaning using a single column layout. See 'protected/views/layouts/column1.php'.
	 */
	public $layout='//layouts/install';
	public $breadcrumbs=array();

	public function init()
	{
		if (defined('RE_DESK_INSTALLED'))
			$this->redirect($this->createAbsoluteUrl('/'));
	}

	public function actionIndex()
	{
		if ($_POST['accept'])
			$this->redirect($this->createAbsoluteUrl('/install/step2'));

		$this->render('index');
	}

	public function actionStep2()
	{
		if ($_POST['ok'])
			$this->redirect($this->createAbsoluteUrl('/install/step3'));

		$php_support = version_compare(phpversion(), self::PHP_VERSION) != - 1;
		$root_dir = dirname(__FILE__) . '/../../';

		$config = $root_dir . '/protected/config/' . self::CONFIG_FILE_NAME;
		$config_cron = $root_dir . '/protected/config/' . self::CRON_CONFIG_FILE_NAME;
		$assets_dir = $root_dir . '/assets/';
		$runtime_dir = $root_dir . '/protected/runtime/';

		if (!is_file($config))
			@file_put_contents($config, '');

		if (!is_file($config_cron))
			@file_put_contents($config_cron, '');

		if (!is_dir($assets_dir))
			@mkdir($assets_dir);

		if (!is_dir($runtime_dir))
			@mkdir($runtime_dir);

		@chmod($config, 0666);
		@chmod($config_cron, 0666);
		@chmod($assets_dir, 0777);
		@chmod($runtime_dir, 0777);

		$config_writable = is_writable($config);
		$cron_config_writable = is_writable($config_cron);
		$assets_writable = is_writable($assets_dir);
		$runtime_writable = is_writable($runtime_dir);

		$this->render('step2',
		array (
			'php_support'          => $php_support,
			'safe_mode'            => !$this->getIni('safe_mode'),
			'mysql_support'        => count(array_intersect(array('pdo_mysql', 'PDO'), get_loaded_extensions())),
			'file_upload'          => $this->getIni('file_uploads'),
			'curl_support'         => in_array('curl', get_loaded_extensions()),
			'config_writable'      => $config_writable,
			'cron_config_writable' => $cron_config_writable,
			'assets_writable'      => $assets_writable,
			'runtime_writable'     => $runtime_writable,
			'short_tags'           => $this->getIni('short_open_tag'),
		));
	}

	public function actionStep3()
	{
		if (Yii::app()->request->isAjaxRequest)
		{
			$dsn = "mysql:host=$_REQUEST[mysql_host];dbname=$_REQUEST[mysql_db]";

			try {
				$connection = new CDbConnection($dsn, $_REQUEST['mysql_user'], $_REQUEST['mysql_password']);
				$connection->active = true;
			} catch (Exception $e) {
				echo "Failed to connect to your database. Please check your settings.";
			}

			if (empty($_REQUEST['admin_email']))
				echo "Please input admin email.";

			Yii::app()->end();
		}

		if (!empty($_POST['ok']))
		{
			$dsn = "mysql:host=$_REQUEST[mysql_host];dbname=$_REQUEST[mysql_db]";

			$settings = array (
				'components' => array (
					'db' => array (
						'connectionString' => $dsn,
						'emulatePrepare'   => true,
						'username'         => $_REQUEST['mysql_user'],
						'password'         => $_REQUEST['mysql_password'],
						'charset'          => 'utf8',
						'enableProfiling'  => false
					),
				),
				'params' => array (
					'adminEmail' => $_REQUEST['admin_email'],
				)
			);

			$cron_settings = array (
				'components' => array (
					'request' => array (
						'hostInfo' => 'http://' . $_REQUEST['server_host'],
						'baseUrl'  => '/',
					),
				)
			);

			$this->writeConfig($settings);
			$this->writeConfig($cron_settings, false, true);

			$connection = new CDbConnection($dsn, $_REQUEST['mysql_user'], $_REQUEST['mysql_password']);
			$connection->active = true;

			$this->importDump($connection);

			$command = $connection->createCommand('
				INSERT INTO tbl_users
					(username, password, email, superuser, status, is_worker)
				VALUES
				 	("admin", :password, :email, 1, 1, 1)
				');

			$password = md5('admin');

			Yii::app()->session['admin_credentials'] = array (
				'username' => $_REQUEST['admin_email'],
				'password' => $_REQUEST['admin_password'],
			);

			$command->bindParam(':password', $password);
			$command->bindParam(':email', $_REQUEST['admin_email']);
			$command->execute();

			$connection->createCommand('UPDATE tbl_settings SET value = :value WHERE label = "company_name"')
				->bindParam(':value', $_REQUEST['company_name'])
				->execute();

			$this->redirect($this->createAbsoluteUrl('install/step4'));
		}

		$dir_name = str_replace(array('\\', 'install', '//'), '/', dirname($_SERVER['PHP_SELF']));
		$this->render('step3', array (
			'dir_name' => ($dir_name == '/') ? '' : $dir_name)
		);
	}

	public function actionStep4()
	{
		if (!empty($_REQUEST['ok']))
		{
			$fn = dirname(__FILE__) . '/../config/' . self::CONFIG_FILE_NAME;
			$conf = include($fn);

			$db_conf = $conf['components']['db'];

			$connection = new CDbConnection(
				$db_conf['connectionString'],
				$db_conf['username'],
				$db_conf['password']
			);

			$connection->active = true;

			$connection->createCommand('
					UPDATE tbl_settings SET value = :value WHERE label = "license_number"
				')->execute(array('value' => $_REQUEST['license_number']));

			$connection->createCommand('
					UPDATE tbl_settings SET value = :value WHERE label = "app_code"
				')->execute(array('value' => base64_encode(time() . '_' . $db_conf['username'])));

			$this->writeConfig($conf, true);

			$db = Yii::createComponent(array(
				'class' => 'CDbConnection',
				'connectionString' => $db_conf['connectionString'],
				'emulatePrepare' => true,
				'username' => $db_conf['username'],
				'password' => $db_conf['password'],
				'charset' => 'utf8',
				'enableProfiling' => false,
			));

			Yii::app()->setComponent('db', $db);

			$identity = new UserIdentity(
				Yii::app()->session['admin_credentials']['username'],
				'admin'
			);

			$identity->authenticate();

			Yii::app()->user->login($identity, 3600 * 24 * 30);

			$this->redirect($this->createAbsoluteUrl('/'));
		}

		$this->render('step4');
	}

	public function getIni($ini_param)
	{
		$res = ini_get($ini_param);

		return (intval($res) || !strcasecmp($res, 'on')) ? true : false;
	}

	private function importDump(CDbConnection $connection)
	{
		$f = fopen(dirname(__FILE__) . "/../migrations/demo.sql", "r");

		if ($f)
		{
			$q = '';

			while(!feof($f))
			{
				$q .= fgets($f);

				if (substr(rtrim($q), -1) == ';')
				{
					$connection->createCommand($q)->execute();
					$q = '';
				}
			}
		}
	}

	private function writeConfig($params, $finish = false, $cron = false)
	{
		$fn = dirname(__FILE__) . '/../config/' . ($cron ? self::CRON_CONFIG_FILE_NAME : self::CONFIG_FILE_NAME);

		$installed = $finish ? 'define("RE_DESK_INSTALLED", true);' : '';

		$conf = "<?php\n\n $installed \n \n return " . var_export($params, true) . ';';

		file_put_contents($fn, $conf);

		return true;
	}

	public function actionBulk()
	{
		$root_dir = dirname(__FILE__) . '/../../';
		$assets_dir = $root_dir . '/assets/';
		$runtime_dir = $root_dir . '/protected/runtime/';

		if (!is_dir($assets_dir))
			@mkdir($assets_dir);

		if (!is_dir($runtime_dir))
			@mkdir($runtime_dir);

		@chmod($assets_dir, 0777);
		@chmod($runtime_dir, 0777);

		$dsn = "mysql:host=$_REQUEST[mysql_host];dbname=$_REQUEST[mysql_db]";

		$settings = array (
			'components' => array (
				'db' => array (
					'connectionString' => $dsn,
					'emulatePrepare'   => true,
					'username'         => $_REQUEST['mysql_user'],
					'password'         => $_REQUEST['mysql_password'],
					'charset'          => 'utf8',
					'enableProfiling'  => false
				),
			),
			'params' => array (
				'adminEmail'    => $_REQUEST['admin_email'],
				'helpdesk_name' => $_REQUEST['helpdesk_name']
			)
		);

		$cron_settings = array (
			'components' => array (
				'request' => array (
					'hostInfo' => 'http://' . $_REQUEST['server_host'],
					'baseUrl'  => '',
				),
			)
		);

		$this->writeConfig($settings, true);
		$this->writeConfig($cron_settings, false, true);

		$connection = new CDbConnection($dsn, $_REQUEST['mysql_user'], $_REQUEST['mysql_password']);
		$connection->active = true;

		$this->importDump($connection);

		$command = $connection->createCommand('
				INSERT INTO tbl_users
					(username, password, email, superuser, status, is_worker)
				VALUES
				 	("admin", :password, :email, 1, 1, 1)
				');

		$password = md5($_REQUEST['admin_password']);

		Yii::app()->session['admin_credentials'] = array (
			'username' => $_REQUEST['admin_email'],
			'password' => $_REQUEST['admin_password'],
		);

		$command->bindParam(':password', $password);
		$command->bindParam(':email', $_REQUEST['admin_email']);
		$command->execute();

		$connection->createCommand('UPDATE tbl_settings SET value = :value WHERE label = "company_name"')
			->bindParam(':value', $_REQUEST['company_name'])
			->execute();

		$connection->createCommand('UPDATE tbl_settings SET value = ' . (time() + 60 * 60 * 24 * 30) . ' WHERE label = "paid_until"');

		die('installed');
	}

	public function actionSmart()
	{
		$root_dir = dirname(__FILE__) . '/../../';
		$assets_dir = $root_dir . '/assets/';
		$runtime_dir = $root_dir . '/protected/runtime/';

		if (!is_dir($assets_dir))
			@mkdir($assets_dir);

		if (!is_dir($runtime_dir))
			@mkdir($runtime_dir);

		@chmod($assets_dir, 0777);
		@chmod($runtime_dir, 0777);

		$dsn = "mysql:host=$_REQUEST[mysql_host];dbname=$_REQUEST[mysql_db]";

		$settings = array (
			'components' => array (
				'db' => array (
					'connectionString' => $dsn,
					'emulatePrepare'   => true,
					'username'         => $_REQUEST['mysql_user'],
					'password'         => $_REQUEST['mysql_password'],
					'charset'          => 'utf8',
					'enableProfiling'  => false
				),
			),
			'params' => array (
				'adminEmail'    => $_REQUEST['admin_email'],
				'helpdesk_name' => $_REQUEST['helpdesk_name']
			)
		);

		$cron_settings = array (
			'components' => array (
				'request' => array (
					'hostInfo' => 'http://' . $_REQUEST['server_host'],
					'baseUrl'  => '',
				),
			)
		);

		$this->writeConfig($settings, true);
		$this->writeConfig($cron_settings, false, true);

		$connection = new CDbConnection($dsn, $_REQUEST['mysql_user'], $_REQUEST['mysql_password']);
		$connection->active = true;

		$this->importDump($connection);

		$command = $connection->createCommand('
				INSERT INTO tbl_users
					(username, password, email, superuser, status, is_worker)
				VALUES
				 	("admin", :password, :email, 1, 1, 1)
				');

		$password = md5($_REQUEST['admin_password']);

		Yii::app()->session['admin_credentials'] = array (
			'username' => $_REQUEST['admin_email'],
			'password' => $_REQUEST['admin_password'],
		);

		$command->bindParam(':password', $password);
		$command->bindParam(':email', $_REQUEST['admin_email']);
		$command->execute();

		$connection->createCommand('UPDATE tbl_settings SET value = :value WHERE label = "company_name"')
			->bindParam(':value', $_REQUEST['company_name'])
			->execute();

		$connection->createCommand('UPDATE tbl_settings SET value = ' . (time() + 60 * 60 * 24 * 30) . ' WHERE label = "paid_until"');

		die('installed');
	}
}