<?php
/***************************************************************************
 *                                                                          *
 *				   (c) 2013 Re:Desk Development Team    				   *
 *                                                                          *
 * This  is  commercial  software,  only  users  who have purchased a valid *
 * license  and  accept  to the terms of the  License Agreement can install *
 * and use this program.                                                    *
 *                                                                          *
 ****************************************************************************
 * PLEASE READ THE FULL TEXT  OF THE SOFTWARE  LICENSE   AGREEMENT  IN  THE *
 * "copyright.txt" FILE PROVIDED WITH THIS DISTRIBUTION PACKAGE.            *
 ****************************************************************************/

class TicketMessageController extends HDController
{
	/**
	 * @var string the default layout for the views. Defaults to '//layouts/column2', meaning
	 * using two-column layout. See 'protected/views/layouts/column2.php'.
	 */
	public $layout='//layouts/column2';

	/**
	 * @return array action filters
	 */
	public function filters()
	{
		return array(
			'rights', // perform access control for CRUD operations
		);
	}

	public function allowedActions()
	{
		return 'preview, download, previewMessage';
	}

	/**
	 * Updates a particular model.
	 * If update is successful, the browser will be redirected to the 'view' page.
	 * @param integer $id the ID of the model to be updated
	 */
	public function actionUpdate($id)
	{
		if (Yii::app()->request->isAjaxRequest)
		{
			// update message
			if (isset($_POST['TicketMessage']))
			{
				$model = $this->loadModel($id);
				$model->addAttachments();

				$model->attributes = $_POST['TicketMessage'];
				$model->save();

				$this->renderPartial('_list_message',array(
					'model'=>$model,
					'ajax' => true,
				), false, true);

				Yii::app()->end();
			}

			// render form
			$model=$this->loadModel($id);

			$this->renderPartial('_form',array(
				'model'=>$model,
				'ajax' => true,
			), false, true);

			Yii::app()->end();
		}
	}

	/**
	 * Deletes a particular model.
	 * If deletion is successful, the browser will be redirected to the 'admin' page.
	 * @param integer $id the ID of the model to be deleted
	 */
	public function actionDelete($id)
	{
		/**
		 * @var TicketMessage $message
		 */
		$message = $this->loadModel($id);

		foreach ($message->attachments as $attachment)
			$attachment->delete();

		$ticket_id = $message->ticket_id;
		$message->delete();

		$this->redirect($this->createUrl('ticket/view', array('id' => $ticket_id)));
	}

	/**
	 * Returns the data model based on the primary key given in the GET variable.
	 * If the data model is not found, an HTTP exception will be raised.
	 * @param integer the ID of the model to be loaded
	 * @return TicketMessage
	 */
	public function loadModel($id)
	{
		$model=TicketMessage::model()->findByPk($id);
		if($model===null)
			throw new CHttpException(404, _t('page does not exist'));
		return $model;
	}

	/**
	 * Performs the AJAX validation.
	 * @param CModel the model to be validated
	 */
	protected function performAjaxValidation($model)
	{
		if(isset($_POST['ajax']) && $_POST['ajax']==='ticket-message-form')
		{
			echo CActiveForm::validate($model);
			Yii::app()->end();
		}
	}

	public function actionDownload($id)
	{
		/** @var $attachment MessageAttachment */
		$attachment = MessageAttachment::model()->findByPk($id);

		if (!empty($attachment))
		{
			header("Content-Type: " . $attachment->file_type);
			header("Content-disposition: attachment; filename=" . $attachment->file_name);
			header("Pragma: no-cache");
			echo $attachment->content;
			exit;
		}
		else
			throw new CHttpException(404, _t('page does not exist'));
	}

	public function actionAssignMessage()
	{
		if (Yii::app()->request->isAjaxRequest)
		{
			$message_id = Yii::app()->request->getPost('message_id');
			$post_message = Yii::app()->request->getPost('TicketMessage');
			$user_id = $post_message['assign_id'];

			/**
			 * @var TicketMessage $message
			 */
			$message = TicketMessage::model()->findByPk($message_id);
			if ($message)
			{
				$message->assign_id = $user_id;
				$message->save();
			}

			Yii::app()->end();
		}
	}

	public function actionPreview($id)
	{
		/**
		 * @var MessageAttachment $attach
		 */
		$attach = MessageAttachment::model()->findByPk($id);

		if ($attach)
			$attach->showImage();

		Yii::app()->end();
	}

	public function actionPreviewMessage()
	{
		$message = new TicketMessage();
		$message->message = $_REQUEST['message'];

		echo $message->show(false);
	}
}
