<?php

/**
 * Class EmailAccounts
 *
 * @property int $id
 * @property string $email_address
 * @property string $email_password
 * @property string $email_transport
 * @property string $email_host
 * @property int $email_port
 * @property string $smtp_host
 * @property string $smtp_port
 * @property string $smtp_encryption
 * @property string $email_name
 * @property int $use_ssl_email
 * @property int $leave_copy
 * @property int $department
 */

class EmailAccounts extends CActiveRecord
{
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'tbl_email_accounts';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		$rules = array (
			array('email_address, email_password, email_host, email_port, email_name, smtp_host, smtp_port, smtp_encryption', 'required'),
			array('email_address', 'email', 'message' => _t('email incorrect')),
			//array('email_address', 'checkRoot', 'message' => _t('email incorrect')),
			array('department, use_ssl_email, leave_copy', 'safe'),
			array('email_port', 'numerical','integerOnly'=>true),
		);

		return $rules;
	}

	public function attributeLabels()
	{
		return array(
			'email_address'   => _t("email address"),
			'email_password'  => _t("email password"),
			'email_transport' => _t("email transport (smtp, imap...)"),
			'email_host'      => _t("imap host"),
			'email_port'      => _t("imap port"),
			'email_name'      => _t("email name"),
			'smtp_host'       => _t("smtp host"),
			'smtp_port'       => _t("smtp port"),
			'smtp_encryption' => _t("smtp encryption"),
			'use_ssl_email'   => _t("use ssl imap"),
			'leave_copy'      => _t("leave message"),
			'department'      => _t('department'),
 		);
	}

	public function checkRoot($attribute)
	{
		$email = $this->$attribute;

		$domain = substr(strrchr(Settings::get('email_address'), "@"), 1);
		$this_email_domain = substr(strrchr($email, "@"), 1);

		if ($domain != $this_email_domain) {
			Yii::app()->user->setFlash('error', str_replace(':domain', $domain, _t('email address mismatch root domain')));
			return false;
		}

		return true;
	}
}