<?php
/***************************************************************************
 *                                                                          *
 *				   (c) 2013 Re:Desk Development Team    				    *
 *                                                                          *
 * This  is  commercial  software,  only  users  who have purchased a valid *
 * license  and  accept  to the terms of the  License Agreement can install *
 * and use this program.                                                    *
 *                                                                          *
 ****************************************************************************
 * PLEASE READ THE FULL TEXT  OF THE SOFTWARE  LICENSE   AGREEMENT  IN  THE *
 * "copyright.txt" FILE PROVIDED WITH THIS DISTRIBUTION PACKAGE.            *
 ****************************************************************************/

/**
 * This is the model class for table "tbl_ticket_category".
 *
 * The followings are the available columns in table 'tbl_ticket_category':
 * @property integer $id
 * @property string $name
 * @property integer $default_category
 * @property string $company_id
 * @property string $code
 * @property string $translations
 * @property string $lang_name
 *
 * The followings are the available model relations:
 * @property Ticket[] $tickets
 */
class TicketCategory extends CActiveRecord
{
	private $_lang_name;

	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return TicketCategory the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'tbl_ticket_category';
	}

	public function getLang_Name()
	{
		if ($this->_lang_name)
			return $this->_lang_name;

		$translations = CJSON::decode($this->translations);

		if (!empty($translations[Yii::app()->language]))
			$this->_lang_name = $translations[Yii::app()->language];
		else
			$this->_lang_name = reset($translations);

		return $this->_lang_name;
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('translations', 'required'),
			array('default_category', 'numerical', 'integerOnly'=>true),
			array('name', 'length', 'max'=>255),
			array('company_id', 'length', 'max'=>20),
			array('code', 'length', 'max'=>16),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, name, default_category, company_id, code', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'tickets' => array(self::HAS_MANY, 'Ticket', 'category_id'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'name' => 'Name',
			'default_category' => 'Default Category',
			'company_id' => 'Company',
			'code' => 'Code',
			'translations' => 'Translations',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('name',$this->name,true);
		$criteria->compare('default_category',$this->default_category);
		$criteria->compare('company_id',$this->company_id,true);
		$criteria->compare('code',$this->code,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	public function findAllFree($current_id = 0)
	{
		$used_categories = Yii::app()->db->createCommand()
			->select('department')
			->from('tbl_email_accounts')
			->where('department != 0')->queryColumn();

		$categories = [0];

		return array_merge($categories, $this->findAll(empty($used_categories) ? null : array('condition' => 'id NOT IN (SELECT department FROM tbl_email_accounts WHERE department != 0 AND id !=' . (empty($current_id) ? 0 : intval($current_id)) . ')')));
	}
}